
.. _paths:

Available Paths
---------------

Paths are defined for each public data release, any internal SDSS releases, as well as for "working" paths not included in any data release.
The available paths for each release are shown below.  To learn how to add a new path, see `Add Paths into the
Tree <https://sdss-tree.readthedocs.io/en/latest/paths.html>`_ and follow the instructions.

Current Working Paths

* :ref:`sdsswork <sdsswork>` - the latest "working" path definitions
* :ref:`sdss5<sdss5>` - temporary working paths for SDSS-V

Public Data Release Paths

* :ref:`DR16 <dr16>` - paths defined for public data release 16
* :ref:`DR15 <dr15>`
* :ref:`DR14 <dr14>`
* :ref:`DR13 <dr13>`
* :ref:`DR12 <dr12>`
* :ref:`DR11 <dr11>`
* :ref:`DR10 <dr10>`
* :ref:`DR9 <dr9>`
* :ref:`DR8<dr8>`

Internal SDSS Release Paths

* :ref:`MPL-9<mpl9>` - MaNGA Product Launch 9
* :ref:`MPL-8<mpl8>`
* :ref:`MPL-7<mpl7>`
* :ref:`MPL-6<mpl6>`
* :ref:`MPL-5<mpl5>`
* :ref:`MPL-4<mpl4>`
* :ref:`MPL-3<mpl3>`


Lastest Path Evolution
----------------------

``sdss_access`` paths sometimes change between various SDSS data releases.  Here we show changes for the latest public data release.  See
the :ref:`complete path evolution <paths-evolution>` for a full list of changes over all releases.

.. changelog:: sdss_access.path.changelog:compute_changelog
   :prog: changes
   :drs: latest

